@@ -1,5 +1,5 @@
 """
-Views for the wagtail admin dashbaord.
+Views for the wagtail admin dashboard.
 """
 
 from django.http import HttpResponse
@@ -14,7 +14,9 @@ def index(request):
     """
     The wagtail-cache admin panel.
     """
-    return render(request, 'wagtailcache/index.html', {'cache_icon': CACHE_ICON})
+    return render(
+        request, "wagtailcache/index.html", {"cache_icon": CACHE_ICON}
+    )
 
 
 def clear(request):
